Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Format ¶
type Format interface {
Parse(data []byte) Deck
Render(d Deck) []byte
ExtractTitle(content string) string
DefaultFile() string
RenderSlide(s Slide) string
RenameSlide(s Slide, name string) Slide
NewSlide(title string) Slide
RenameDeck(d Deck, name string) Deck
Scaffold(title, slug string) []ScaffoldFile
PostScaffoldCmd() []string
}
Format defines how a presentation file is parsed and rendered.
type ScaffoldFile ¶
ScaffoldFile describes a file or directory to create when scaffolding a new presentation.
Click to show internal directories.
Click to hide internal directories.